#include <FL/Fl.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Progress.H>
#include <FL/Fl_Slider.H>
#include <FL/Fl_Double_Window.H>

static Fl_Progress *bar1;
static Fl_Box *bar2;
static int real_maximum = 0;

const double mbar_size = 0.33;  /* between 0.0 and 1.0 */
const int dnbx_border = 2;  /* FL_DOWN_BOX border size */

static void callback(Fl_Widget *w)
{
  int val = (int)((Fl_Slider *)w)->value() % real_maximum;

  bar1->value(val);

  if (val > (mbar_size * bar1->maximum())) {
    bar2->resize(bar2->x(), bar2->y(),
                 (int)(val / bar1->maximum() * bar1->w()) - mbar_size*bar1->w() - dnbx_border*2,
                 bar2->h());
  } else {
    bar2->resize(bar2->x(), bar2->y(), 0, bar2->h());
  }
  bar2->parent()->redraw();
}

int main(void)
{
  Fl_Double_Window *win = new Fl_Double_Window(320, 90, "Test");
  {
    bar1 = new Fl_Progress(10, 10, 300, 30);
    bar1->box(FL_DOWN_BOX);
    bar1->minimum(0);
    bar1->maximum(1000);
    bar1->color(fl_darker(FL_GRAY));
    bar1->selection_color(fl_lighter(FL_BLUE));
    bar1->value(0);

    real_maximum = bar1->maximum() + mbar_size*bar1->maximum();

    bar2 = new Fl_Box(bar1->x() + dnbx_border, bar1->y() + dnbx_border, 0, bar1->h() - dnbx_border*2);
    bar2->box(FL_FLAT_BOX);
    bar2->color(bar1->color());

   { Fl_Slider *o = new Fl_Slider(10, 50, 300, 30);
    o->type(1);
    o->minimum(0);
    o->maximum(real_maximum*5);
    o->color(fl_darker(FL_GRAY));
    o->value(0);
    o->slider_size(0.16);
    o->callback(callback); }
  }
  win->end();
  win->show();
  Fl::run();

  return 0;
}

